# Changelog

## [2.9.0](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.8.1...aegis-v2.9.0) (2025-09-16)


### Features

* **client:** updating client works i think ([0e3e6d9](https://github.com/AEGIS-GAME/aegis/commit/0e3e6d99776d6439f204458fbc90b2a4600c476a))


### Bug Fixes

* **aegis:** always remove prefix to version begfore writing/comparing ([37d4181](https://github.com/AEGIS-GAME/aegis/commit/37d4181378fba7d2b52d60e214a4c770629ba014))
* **updating:** remove debug, check for None ([de94e55](https://github.com/AEGIS-GAME/aegis/commit/de94e55907452ff8a3a9a6707ead9d1ba2f95c21))
* **updating:** some things ([efcc5d0](https://github.com/AEGIS-GAME/aegis/commit/efcc5d0a332167388942b8ffdd0e5ff7cc502a81))

## [2.8.1](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.8.0...aegis-v2.8.1) (2025-09-15)


### Bug Fixes

* add things ([425a407](https://github.com/AEGIS-GAME/aegis/commit/425a407464e62a06eefc8f03aabc418a01f0fe59))
* **aegis:** properly create client version file from aegis init ([cc6097d](https://github.com/AEGIS-GAME/aegis/commit/cc6097de9a3936fee9660b42c8edfa70ef673222))

## [2.8.0](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.6...aegis-v2.8.0) (2025-09-15)


### Features

* **client:** update client feature ([41963ac](https://github.com/AEGIS-GAME/aegis/commit/41963ac38061bdfd20b010933603e7a94a80a10e))


### Bug Fixes

* **aegis:** clean up client zip after installing ([a664e89](https://github.com/AEGIS-GAME/aegis/commit/a664e897831c6762f10e54b3a507cdc3e0d6c17e))
* client jsut checks version mismatch, aegis update just downloads ([85877fa](https://github.com/AEGIS-GAME/aegis/commit/85877fa7f45afe54710a6d071553e8604dc96967))
* using client-version.txt file for client version ([3fa68b1](https://github.com/AEGIS-GAME/aegis/commit/3fa68b1a468199095fc9571f15172c8c0c46f65e))


### Documentation

* **functions:** functions not following google style docstrings ([#61](https://github.com/AEGIS-GAME/aegis/issues/61)) ([2ee241b](https://github.com/AEGIS-GAME/aegis/commit/2ee241b120d738b742317ef033bd5a18c5a682fe))

## [2.7.6](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.5...aegis-v2.7.6) (2025-09-15)


### Bug Fixes

* **client win name:** . ([f753c2e](https://github.com/AEGIS-GAME/aegis/commit/f753c2e7860b99f1fce092401b57c2139441f8f0))

## [2.7.5](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.4...aegis-v2.7.5) (2025-09-14)


### Bug Fixes

* **permissions:** write perms ([1b9b956](https://github.com/AEGIS-GAME/aegis/commit/1b9b9563693f54bf4521e64535bf5d2c2d4513c6))

## [2.7.4](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.3...aegis-v2.7.4) (2025-09-14)


### Bug Fixes

* **release name:** . ([c1e0810](https://github.com/AEGIS-GAME/aegis/commit/c1e08103e627b6dc3d8bbb96a5622c464f67abee))

## [2.7.3](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.2...aegis-v2.7.3) (2025-09-14)


### Bug Fixes

* **just to force a aegis release:** . ([36a8b9c](https://github.com/AEGIS-GAME/aegis/commit/36a8b9cebef495eed3ce8f02b813ed2a95fda448))

## [2.7.2](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.1...aegis-v2.7.2) (2025-09-12)


### Bug Fixes

* **ci:** release wrong platforms ([ecbec71](https://github.com/AEGIS-GAME/aegis/commit/ecbec71816f5f2be925f38ef0fb60ef8a42bbc6c))

## [2.7.1](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.7.0...aegis-v2.7.1) (2025-09-12)


### Bug Fixes

* **workflows:** add missing steps ([4a24ef9](https://github.com/AEGIS-GAME/aegis/commit/4a24ef930a0fa86da488b1dbfcbde4c63feeabad))

## [2.7.0](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.6.4...aegis-v2.7.0) (2025-09-12)


### Features

* **new workflow:** move release into one workflow ([bf76e95](https://github.com/AEGIS-GAME/aegis/commit/bf76e95af4b9afdefd75a0a9cc1c09e1d29505da))

## [2.6.4](https://github.com/AEGIS-GAME/aegis/compare/aegis-v2.6.3...aegis-v2.6.4) (2025-09-12)


### Bug Fixes

* **tryign to force a release:** hate google ([#50](https://github.com/AEGIS-GAME/aegis/issues/50)) ([93179c4](https://github.com/AEGIS-GAME/aegis/commit/93179c4935cf98ee3b50197d0a60b034db0905fd))
